==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathFactoryImpl.h <==
// public class gnu.xml.xpath.XPathFactoryImpl

// class file dependencies
// @dep_class 35e4f8cb68dc6c81 gnu_xml_xpath_XPathFactoryImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33c80e80f1ac94b9 javax_xml_xpath_XPathFactory

// header file dependencies
// @dep_header javax_xml_xpath_XPathFactory

#include "javax/xml/xpath/XPathFactory.h"

#ifndef _JC_gnu_xml_xpath_XPathFactoryImpl_H_
#define _JC_gnu_xml_xpath_XPathFactoryImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_xpath_XPath$object;
struct _jc_javax_xml_xpath_XPathFunctionResolver$object;
struct _jc_javax_xml_xpath_XPathVariableResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs	_jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs	_jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$refs	_jc_gnu_xml_xpath_XPathFactoryImpl$refs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs	_jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$object	_jc_gnu_xml_xpath_XPathFactoryImpl$object;

typedef const struct _jc_gnu_xml_xpath_XPathFactoryImpl$vmethods	_jc_gnu_xml_xpath_XPathFactoryImpl$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtable	_jc_gnu_xml_xpath_XPathFactoryImpl$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtype	_jc_gnu_xml_xpath_XPathFactoryImpl$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *);

// Virtual methods
extern jboolean _jc_gnu_xml_xpath_XPathFactoryImpl$method$getFeature$1f81e149fe4bca3b(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_gnu_xml_xpath_XPathFactoryImpl$method$isObjectModelSupported$d5517493cb54961b(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_xpath_XPathFactoryImpl$method$newXPath$8bbcbddca73498ad(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *);
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$setFeature$907897e626165cee(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$setXPathFunctionResolver$4d1101561d7baed3(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *);
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$setXPathVariableResolver$b5f763d257270ffb(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$getFeature$1f81e149fe4bca3b;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$isObjectModelSupported$d5517493cb54961b;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$newXPath$8bbcbddca73498ad;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$setFeature$907897e626165cee;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$setXPathFunctionResolver$4d1101561d7baed3;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$setXPathVariableResolver$b5f763d257270ffb;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathFactoryImpl$vmethods {
	jboolean	(*getFeature$1f81e149fe4bca3b)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *);
	jboolean	(*isObjectModelSupported$d5517493cb54961b)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*newXPath$8bbcbddca73498ad)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *);
	void	(*setFeature$907897e626165cee)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *, jboolean);
	void	(*setXPathFunctionResolver$4d1101561d7baed3)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *);
	void	(*setXPathVariableResolver$b5f763d257270ffb)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_xpath_XPathFactory$vmethods	javax_xml_xpath_XPathFactory;
	_jc_gnu_xml_xpath_XPathFactoryImpl$vmethods	gnu_xml_xpath_XPathFactoryImpl;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathFactoryImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs {
	struct _jc_object	*variableResolver;
	struct _jc_object	*functionResolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$refs {
    _jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs	gnu_xml_xpath_XPathFactoryImpl;
    _jc_javax_xml_xpath_XPathFactory$sub_refs	javax_xml_xpath_XPathFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_xpath_XPathFactory$sub_nonrefs	javax_xml_xpath_XPathFactory;
    _jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs	gnu_xml_xpath_XPathFactoryImpl;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathFactoryImpl$object {
	_jc_gnu_xml_xpath_XPathFactoryImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathFactoryImpl$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathFactoryImpl$vtype _jc_gnu_xml_xpath_XPathFactoryImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathFactoryImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathFactoryImpl$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathFactoryImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/xpath/XPathFactoryImpl.h <==
// public class gnu.xml.xpath.XPathFactoryImpl

// class file dependencies
// @dep_class 35e4f8cb68dc6c81 gnu_xml_xpath_XPathFactoryImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33c80e80f1ac94b9 javax_xml_xpath_XPathFactory

// header file dependencies
// @dep_header javax_xml_xpath_XPathFactory

#include "javax/xml/xpath/XPathFactory.h"

#ifndef _JC_gnu_xml_xpath_XPathFactoryImpl_H_
#define _JC_gnu_xml_xpath_XPathFactoryImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_xpath_XPath$object;
struct _jc_javax_xml_xpath_XPathFunctionResolver$object;
struct _jc_javax_xml_xpath_XPathVariableResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs	_jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs	_jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$refs	_jc_gnu_xml_xpath_XPathFactoryImpl$refs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs	_jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathFactoryImpl$object	_jc_gnu_xml_xpath_XPathFactoryImpl$object;

typedef const struct _jc_gnu_xml_xpath_XPathFactoryImpl$vmethods	_jc_gnu_xml_xpath_XPathFactoryImpl$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtable	_jc_gnu_xml_xpath_XPathFactoryImpl$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtype	_jc_gnu_xml_xpath_XPathFactoryImpl$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_xpath_XPathFactoryImpl$method$getFeature$1f81e149fe4bca3b(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_XPathFactoryImpl$method$isObjectModelSupported$d5517493cb54961b(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_xpath_XPathFactoryImpl$method$newXPath$8bbcbddca73498ad(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$setFeature$907897e626165cee(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$setXPathFunctionResolver$4d1101561d7baed3(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_xpath_XPathFactoryImpl$method$setXPathVariableResolver$b5f763d257270ffb(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$getFeature$1f81e149fe4bca3b;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$isObjectModelSupported$d5517493cb54961b;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$newXPath$8bbcbddca73498ad;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$setFeature$907897e626165cee;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$setXPathFunctionResolver$4d1101561d7baed3;
extern _jc_method _jc_gnu_xml_xpath_XPathFactoryImpl$method_info$setXPathVariableResolver$b5f763d257270ffb;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathFactoryImpl$vmethods {
	jboolean	(*getFeature$1f81e149fe4bca3b)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jboolean	(*isObjectModelSupported$d5517493cb54961b)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newXPath$8bbcbddca73498ad)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *) _JC_JCNI_ATTR;
	void	(*setFeature$907897e626165cee)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
	void	(*setXPathFunctionResolver$4d1101561d7baed3)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setXPathVariableResolver$b5f763d257270ffb)(_jc_env *, struct _jc_gnu_xml_xpath_XPathFactoryImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_xpath_XPathFactory$vmethods	javax_xml_xpath_XPathFactory;
	_jc_gnu_xml_xpath_XPathFactoryImpl$vmethods	gnu_xml_xpath_XPathFactoryImpl;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathFactoryImpl$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathFactoryImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs {
	struct _jc_object	*variableResolver;
	struct _jc_object	*functionResolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$refs {
    _jc_gnu_xml_xpath_XPathFactoryImpl$sub_refs	gnu_xml_xpath_XPathFactoryImpl;
    _jc_javax_xml_xpath_XPathFactory$sub_refs	javax_xml_xpath_XPathFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_xpath_XPathFactory$sub_nonrefs	javax_xml_xpath_XPathFactory;
    _jc_gnu_xml_xpath_XPathFactoryImpl$sub_nonrefs	gnu_xml_xpath_XPathFactoryImpl;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathFactoryImpl$object {
	_jc_gnu_xml_xpath_XPathFactoryImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathFactoryImpl$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathFactoryImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathFactoryImpl$vtype _jc_gnu_xml_xpath_XPathFactoryImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathFactoryImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathFactoryImpl$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathFactoryImpl_H_ */
